# coding: utf-8

"""
    Simple Game Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from tangled-game-api-python.models.get_legal_moves200_response import GetLegalMoves200Response

class TestGetLegalMoves200Response(unittest.TestCase):
    """GetLegalMoves200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetLegalMoves200Response:
        """Test GetLegalMoves200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetLegalMoves200Response`
        """
        model = GetLegalMoves200Response()
        if include_optional:
            return GetLegalMoves200Response(
                legal_moves = [[0,1,2],[1,2,3],[2,0,0]]
            )
        else:
            return GetLegalMoves200Response(
        )
        """

    def testGetLegalMoves200Response(self):
        """Test GetLegalMoves200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
